@@ -12,7 +12,7 @@ from mezzanine.blog.models import BlogPost
 from mezzanine.conf import settings
 
 from mezzanine.core.models import CONTENT_STATUS_PUBLISHED
-from mezzanine.pages.models import RichTextPage
+from mezzanine.pages.models import Page, RichTextPage
 from mezzanine.utils.tests import TestCase
 
 
@@ -49,3 +49,10 @@ class BlogTests(TestCase):
         self.assertTrue(len(response.redirect_chain) > 0)
         redirect_path = urlparse(response.redirect_chain[0][0]).path
         self.assertEqual(redirect_path, settings.LOGIN_URL)
+
+    def test_blog_post_list_can_use_any_page_type(self):
+        """Test that the blog post list can use any Page type."""
+        slug = settings.BLOG_SLUG or "/"
+        Page.objects.create(title="blog", slug=slug)
+        response = self.client.get(reverse("blog_post_list"))
+        self.assertEqual(response.status_code, 200)
