@@ -89,29 +89,24 @@ class PageMiddleware(object):
             bits = (settings.LOGIN_URL, REDIRECT_FIELD_NAME, path)
             return redirect("%s?%s=%s" % bits)
 
-        # Here we do a wacky check with non-page views and 404s.
-        # Basically if the view function isn't the page view and
-        # raises a 404, but also matches an exact page slug, we then
-        # forget about the non-page view, and run the page view
-        # with the correct args.
-        # This check allows us to set up pages with URLs that also
-        # match non-page urlpatterns, for example a page could be
-        # created with the URL /blog/about/, which would match the
-        # blog urlpattern, and assuming there wasn't a blog post
-        # with the slug "about", would raise a 404.
-        try:
-            response = view_func(request, *view_args, **view_kwargs)
-        except Http404:
-            if (page.slug == slug and view_func != page_view and
-                    page.content_model != 'link'):
-                # Matched a non-page urlpattern, but got a 404
-                # for a URL that matches a valid page slug, so
-                # use the page view.
-                response = page_view(request, slug, **view_kwargs)
-            else:
-                raise
+        # If the view isn't Mezzanine's page view, try to return the result
+        # immediately. In the case of a 404 with an URL slug that matches a
+        # page exactly, swallow the exception and try Mezzanine's page view.
+        #
+        # This allows us to set up pages with URLs that also match non-page
+        # urlpatterns. For example, a page could be created with the URL
+        # /blog/about/, which would match the blog urlpattern, and assuming
+        # there wasn't a blog post with the slug "about", would raise a 404
+        # and subsequently be rendered by Mezzanine's page view.
+        if view_func != page_view:
+            try:
+                return view_func(request, *view_args, **view_kwargs)
+            except Http404:
+                if page.slug != slug:
+                    raise
 
         # Run page processors.
+        extra_context = {}
         model_processors = page_processors.processors[page.content_model]
         slug_processors = page_processors.processors["slug:%s" % page.slug]
         for (processor, exact_page) in slug_processors + model_processors:
@@ -120,11 +115,11 @@ class PageMiddleware(object):
             processor_response = processor(request, page)
             if isinstance(processor_response, HttpResponse):
                 return processor_response
-            elif processor_response and hasattr(response, "context_data"):
+            elif processor_response:
                 try:
-                    for k in processor_response:
-                        if k not in response.context_data:
-                            response.context_data[k] = processor_response[k]
+                    for k, v in processor_response.items():
+                        if k not in extra_context:
+                            extra_context[k] = v
                 except (TypeError, ValueError):
                     name = "%s.%s" % (processor.__module__, processor.__name__)
                     error = ("The page processor %s returned %s but must "
@@ -132,4 +127,4 @@ class PageMiddleware(object):
                              (name, type(processor_response)))
                     raise ValueError(error)
 
-        return response
+        return page_view(request, slug, extra_context=extra_context)
